summaryrefslogtreecommitdiff
path: root/src/components/include/application_manager/rpc_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/include/application_manager/rpc_service.h')
-rw-r--r--src/components/include/application_manager/rpc_service.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/src/components/include/application_manager/rpc_service.h b/src/components/include/application_manager/rpc_service.h
index f98cd826f9..630070074a 100644
--- a/src/components/include/application_manager/rpc_service.h
+++ b/src/components/include/application_manager/rpc_service.h
@@ -53,7 +53,7 @@ class RPCService {
/**
* @brief ManageMobileCommand convert message to mobile command and execute it
* @param message pointer to received message
* @param origin origin of command
* @param warning_info warning message to send on a successful response. Only
* applies to requests from mobile.
* @return true if command is executed, otherwise return false
@@ -67,11 +67,17 @@ class RPCService {
/**
* @brief ManageHMICommand convert message to HMI command and execute it
* @param message pointer to received message
+ * @param source source of command
+ * @param warning_info warning message to send on a successful response. Only
+ * applies to requests from HMI.
* @return true if command is executed, otherwise return false
*/
virtual bool ManageHMICommand(const commands::MessageSharedPtr message,
commands::Command::CommandSource source =
commands::Command::SOURCE_HMI) = 0;
+ virtual bool ManageHMICommand(const commands::MessageSharedPtr message,
+ commands::Command::CommandSource source,
+ const std::string warning_info) = 0;
/**
* @brief SendMessageToMobile Put message to the queue to be sent to mobile.
@@ -53,7 +53,7 @@ class RPCService {
* @brief ManageMobileCommand convert message to mobile command and execute it
* @param message pointer to received message
- * @param origin origin of command
+ * @param source source of command
* @param warning_info warning message to send on a successful response. Only
* applies to requests from mobile.